@@ -1,6 +1,6 @@
 from typing import Optional
 
-from .hpysignal import main_window_signal  # 给函数用的，不是拿来调用的
+from .hpysignal import instance_main_win_signal  # 单例模式 信号
 
 io_instance: Optional[open] = None  # 我想用类属性的，但是时间给我干到原来的三倍，傻眼了
 output_data: Optional[str] = None  # 测试用的，获取输出框的数据
@@ -15,11 +15,15 @@ OFF = 1 << 0  # 因为没读到就用这个作为缺省，所以每个参数的(
 
 # 'output_mode'
 RETURN_ONCE = 1 << 0
-RETURN_LIST = 1 << 1
-RETURN_LIST_OUTPUT_IN_ONE_LINE = 1 << 2
+RETURN_ITERABLE = 1 << 1
+RETURN_ITERABLE_OUTPUT_IN_ONE_LINE = 1 << 2
 NO_RETURN = 1 << 3
 NO_RETURN_SINGLE_FUNCTION = 1 << 4
 
+# 将要移除
+RETURN_LIST = 1 << 1
+RETURN_LIST_OUTPUT_IN_ONE_LINE = 1 << 2
+
 
 def write(anything, end="\n") -> None:
     """
@@ -31,7 +35,6 @@ def write(anything, end="\n") -> None:
     """
     io_instance.write(str(anything) + end)
     io_instance.flush()
-    return None
 
 
 def write_without_flush(anything, end="\n") -> None:
@@ -43,7 +46,6 @@ def write_without_flush(anything, end="\n") -> None:
     :return: None
     """
     io_instance.write(str(anything) + end)
-    return None
 
 
 def flush() -> None:
@@ -53,7 +55,6 @@ def flush() -> None:
     :return: None
     """
     io_instance.flush()
-    return None
 
 
 def output(anything) -> None:
@@ -63,8 +64,7 @@ def output(anything) -> None:
     :param anything: 要输出到框体的数据
     :return: None
     """
-    main_window_signal.appendOutPutBox.emit(str(anything))
-    return None
+    instance_main_win_signal.append_output_box.emit(str(anything))
 
 
 def clearOutput() -> None:
@@ -73,8 +73,7 @@ def clearOutput() -> None:
 
     :return: None
     """
-    main_window_signal.clearOutPutBox.emit()
-    return None
+    instance_main_win_signal.clear_output_box.emit()
 
 
 def setOutput(msg: str) -> None:
@@ -84,8 +83,7 @@ def setOutput(msg: str) -> None:
     :param msg: 要输出到框体的数据
     :return: None
     """
-    main_window_signal.setOutPutBox.emit(msg)
-    return None
+    instance_main_win_signal.set_output_box.emit(msg)
 
 
 # 以下是用来传递数据的
@@ -100,7 +98,6 @@ def setIoInstance(instance) -> None:
     """
     global io_instance
     io_instance = instance
-    return None
 
 
 def getIoInstance():
@@ -120,7 +117,6 @@ def setOutPutData(data: str) -> None:
     """
     global output_data
     output_data = data
-    return None
 
 
 def getOutputData():
@@ -129,7 +125,7 @@ def getOutputData():
 
     :return: OutputData
     """
-    main_window_signal.getOutPutBox.emit()
+    instance_main_win_signal.get_output_box.emit()
     return output_data
 
 
